{% load twitter_bootstrap %}

<div class="form-group">
    <label class="sr-only" for="{{ field.auto_id }}">{{ field.label }}{% if field.field.required %}{{ required_suffix }}{% endif %}</label>
    {{ field|add_class:"form-control" }}
</div>
